@@ -112,8 +112,10 @@ free_all(thread_ref_t thread)
 {
 	SOCK *sock_obj = THREAD_ARG(thread);
 
-	DBG("Total read size read = %d Bytes, fd:%d\n",
+#ifdef _GENHASH_DEBUG_
+	fprintf(stderr, "Total read size read = %d Bytes, fd:%d\n",
 	    sock_obj->total_size, sock_obj->fd);
+#endif
 
 	if (sock_obj->buffer)
 		FREE(sock_obj->buffer);
@@ -130,7 +132,9 @@ free_all(thread_ref_t thread)
 int
 epilog(thread_ref_t thread)
 {
-	DBG("Timeout on URL : [%s]\n", req->url);
+#ifdef _GENHASH_DEBUG_
+	fprintf(stderr, "Timeout on URL : [%s]\n", req->url);
+#endif
 	free_all(thread);
 	return 0;
 }
@@ -160,7 +164,9 @@ finalize(thread_ref_t thread)
 		printf ("\nWARNING - Content-Length (%zd) does not match received bytes (%zd).", sock_obj->content_len, sock_obj->rx_bytes);
 	printf("\n\n");
 
-	DBG("Finalize : [%s]\n", req->url);
+#ifdef _GENHASH_DEBUG_
+	fprintf(stderr, "Finalize : [%s]\n", req->url);
+#endif
 	free_all(thread);
 	FREE(digest);
 	return 0;
@@ -279,16 +285,20 @@ http_read_thread(thread_ref_t thread)
 	memset(sock_obj->buffer + sock_obj->size, 0, (size_t)r);
 	r = read(thread->u.f.fd, sock_obj->buffer + sock_obj->size, (size_t)r);
 
-	DBG(" [l:%zd,fd:%d]\n", r, sock_obj->fd);
+#ifdef _GENHASH_DEBUG_
+	fprintf(stderr, " [l:%zd,fd:%d]\n", r, sock_obj->fd);
+#endif
 
 	if (r == 0) {		/* EOF */
 		/* All the HTTP stream has been parsed */
 		finalize(thread);
 	} else if (r == -1) {	/* error */
 		/* We have encountered a real read error */
-		DBG("Read error with server [%s]:%d: %s\n",
+#ifdef _GENHASH_DEBUG_
+		fprintf(stderr, "Read error with server [%s]:%d: %s\n",
 		    req->ipaddress, ntohs(req->addr_port),
 		    strerror(errno));
+#endif
 		exit_code = 1;
 		return epilog(thread);
 	} else {
@@ -352,7 +362,9 @@ http_request_thread(thread_ref_t thread)
 	FREE_CONST(request_host_port);
 
 	/* Send the GET request to remote Web server */
-	DBG("Sending GET request [%s] on fd:%d\n", req->url, sock_obj->fd);
+#ifdef _GENHASH_DEBUG_
+	fprintf(stderr, "Sending GET request [%s] on fd:%d\n", req->url, sock_obj->fd);
+#endif
 	if (req->ssl)
 		ret = ssl_send_request(sock_obj->ssl, str_request, (int)strlen(str_request));
 	else
