@@ -24,9 +24,6 @@
 
 #include <fcntl.h>
 
-/* keepalived include */
-#include "utils.h"
-
 /* genhash includes */
 #include "include/layer4.h"
 
@@ -98,8 +95,10 @@ tcp_socket_state(thread_ref_t thread, thread_func_t func)
 
 	/* Handle connection timeout */
 	if (thread->type == THREAD_WRITE_TIMEOUT) {
-		DBG("TCP connection timeout to [%s]:%d.\n",
+#ifdef _GENHASH_DEBUG_
+		fprintf(stderr, "TCP connection timeout to [%s]:%d.\n",
 		    req->ipaddress, ntohs(req->addr_port));
+#endif
 		thread_close_fd(thread);
 		return connect_timeout;
 	}
@@ -112,8 +111,10 @@ tcp_socket_state(thread_ref_t thread, thread_func_t func)
 
 	/* Connection failed !!! */
 	if (ret) {
-		DBG("TCP getsockopt() failed to [%s]:%d.\n",
+#ifdef _GENHASH_DEBUG_
+		fprintf(stderr, "TCP getsockopt() failed to [%s]:%d.\n",
 		    req->ipaddress, ntohs(req->addr_port));
+#endif
 		thread_close_fd(thread);
 		return connect_error;
 	}
@@ -124,16 +125,20 @@ tcp_socket_state(thread_ref_t thread, thread_func_t func)
 	 * Recompute the write timeout (or pending connection).
 	 */
 	if (status == EINPROGRESS) {
-		DBG("TCP connection to [%s]:%d still IN_PROGRESS.\n",
+#ifdef _GENHASH_DEBUG_
+		fprintf(stderr, "TCP connection to [%s]:%d still IN_PROGRESS.\n",
 		    req->ipaddress, ntohs(req->addr_port));
+#endif
 
 		timer_min = timer_sub_now(thread->sands);
 		thread_add_write(thread->master, func, THREAD_ARG(thread)
 				 , thread->u.f.fd, timer_long(timer_min), true);
 		return connect_in_progress;
 	} else if (status) {
-		DBG("TCP connection failed to [%s]:%d.\n",
+#ifdef _GENHASH_DEBUG_
+		fprintf(stderr, "TCP connection failed to [%s]:%d.\n",
 		    req->ipaddress, ntohs(req->addr_port));
+#endif
 		thread_close_fd(thread);
 		return connect_error;
 	}
@@ -177,15 +182,19 @@ tcp_check_thread(thread_ref_t thread)
 	sock_obj->status = tcp_socket_state(thread, tcp_check_thread);
 	switch (sock_obj->status) {
 	case connect_error:
-		DBG("Error connecting server [%s]:%d.\n",
+#ifdef _GENHASH_DEBUG_
+		fprintf(stderr, "Error connecting server [%s]:%d.\n",
 		    req->ipaddress, ntohs(req->addr_port));
+#endif
 		thread_add_terminate_event(thread->master);
 		return -1;
 		break;
 
 	case connect_timeout:
-		DBG("Timeout connecting server [%s]:%d.\n",
+#ifdef _GENHASH_DEBUG_
+		fprintf(stderr, "Timeout connecting server [%s]:%d.\n",
 		    req->ipaddress, ntohs(req->addr_port));
+#endif
 		thread_add_terminate_event(thread->master);
 		return -1;
 		break;
@@ -207,9 +216,11 @@ tcp_check_thread(thread_ref_t thread)
 						 http_request_thread, sock_obj, 0);
 				thread_del_write(thread);
 			} else {
-				DBG("Connection trouble to: [%s]:%d.\n",
+#ifdef _GENHASH_DEBUG_
+				fprintf(stderr, "Connection trouble to: [%s]:%d.\n",
 				    req->ipaddress,
 				    ntohs(req->addr_port));
+#endif
 				sock_obj->status = connect_error;
 				thread_add_terminate_event(thread->master);
 				return -1;
@@ -232,7 +243,9 @@ tcp_connect_thread(thread_ref_t thread)
 					       | SOCK_CLOEXEC
 #endif
 							     , IPPROTO_TCP)) == -1) {
-		DBG("WEB connection fail to create socket.\n");
+#ifdef _GENHASH_DEBUG_
+		fprintf(stderr, "WEB connection fail to create socket.\n");
+#endif
 		return 0;
 	}
 
