@@ -36,9 +36,7 @@
 #include "vrrp.h"
 #include "vrrp_ipaddress.h"
 #endif
-#ifdef _HAVE_SCHED_RT_
 #include "process.h"
-#endif
 #ifdef _WITH_FIREWALL_
 #include "vrrp_firewall.h"
 #endif
@@ -218,7 +216,7 @@ alloc_global_data(void)
 }
 
 void
-init_global_data(data_t * data, data_t *prev_global_data, bool copy_network_namespace)
+init_global_data(data_t * data, data_t *prev_global_data, bool copy_unchangeable_config)
 {
 	/* If this is a reload and we are running in a network namespace,
 	 * we may not be able to get local_name, so preserve it */
@@ -230,10 +228,14 @@ init_global_data(data_t * data, data_t *prev_global_data, bool copy_network_name
 		data->local_name = prev_global_data->local_name;
 		prev_global_data->local_name = NULL;
 
-		if (copy_network_namespace) {
+		if (copy_unchangeable_config) {
 			FREE_CONST_PTR(data->network_namespace);
 			data->network_namespace = prev_global_data->network_namespace;
 			prev_global_data->network_namespace = NULL;
+
+			FREE_CONST_PTR(data->instance_name);
+			data->instance_name = prev_global_data->instance_name;
+			prev_global_data->instance_name = NULL;
 		}
 	}
 
@@ -271,7 +273,7 @@ init_global_data(data_t * data, data_t *prev_global_data, bool copy_network_name
 	/* If the global and vrrp notify FIFOs are the same, then data will be
 	 * duplicated on the FIFO */
 	if (
-#ifndef _DEBUG_
+#ifndef _ONE_PROCESS_DEBUG_
 	    prog_type == PROG_TYPE_VRRP &&
 #endif
 	    data->notify_fifo.name && data->vrrp_notify_fifo.name &&
@@ -285,7 +287,7 @@ init_global_data(data_t * data, data_t *prev_global_data, bool copy_network_name
 #ifdef _WITH_LVS_
 	/* If the global and LVS notify FIFOs are the same, then data will be
 	 * duplicated on the FIFO */
-#ifndef _DEBUG_
+#ifndef _ONE_PROCESS_DEBUG_
 	if (prog_type == PROG_TYPE_CHECKER)
 #endif
 	{
@@ -367,9 +369,7 @@ free_global_data(data_t * data)
 void
 dump_global_data(FILE *fp, data_t * data)
 {
-#ifdef _HAVE_SCHED_RT_
 	char cpu_str[64];
-#endif
 #ifdef _WITH_VRRP_
 	char buf[64];
 #endif
@@ -441,7 +441,7 @@ dump_global_data(FILE *fp, data_t * data)
 	if (data->lvs_udp_timeout)
 		conf_write(fp, " LVS TCP timeout = %d", data->lvs_udp_timeout);
 #ifdef _WITH_VRRP_
-#ifndef _DEBUG_
+#ifndef _ONE_PROCESS_DEBUG_
 	if (prog_type == PROG_TYPE_VRRP)
 #endif
 		conf_write(fp, " Default interface = %s", data->default_ifp ? data->default_ifp->ifname : DFLT_INT);
@@ -560,7 +560,6 @@ dump_global_data(FILE *fp, data_t * data)
 	conf_write(fp, " VRRP strict mode = %s", data->vrrp_strict ? "true" : "false");
 	conf_write(fp, " VRRP process priority = %d", data->vrrp_process_priority);
 	conf_write(fp, " VRRP don't swap = %s", data->vrrp_no_swap ? "true" : "false");
-#ifdef _HAVE_SCHED_RT_
 	conf_write(fp, " VRRP realtime priority = %u", data->vrrp_realtime_priority);
 	if (CPU_COUNT(&data->vrrp_cpu_mask)) {
 		get_process_cpu_affinity_string(&data->vrrp_cpu_mask, cpu_str, 63);
@@ -570,11 +569,9 @@ dump_global_data(FILE *fp, data_t * data)
 	conf_write(fp, " VRRP realtime limit = %" PRI_rlim_t, data->vrrp_rlimit_rt);
 #endif
 #endif
-#endif
 #ifdef _WITH_LVS_
 	conf_write(fp, " Checker process priority = %d", data->checker_process_priority);
 	conf_write(fp, " Checker don't swap = %s", data->checker_no_swap ? "true" : "false");
-#ifdef _HAVE_SCHED_RT_
 	conf_write(fp, " Checker realtime priority = %u", data->checker_realtime_priority);
 	if (CPU_COUNT(&data->checker_cpu_mask)) {
 		get_process_cpu_affinity_string(&data->checker_cpu_mask, cpu_str, 63);
@@ -584,11 +581,9 @@ dump_global_data(FILE *fp, data_t * data)
 	conf_write(fp, " Checker realtime limit = %" PRI_rlim_t, data->checker_rlimit_rt);
 #endif
 #endif
-#endif
 #ifdef _WITH_BFD_
 	conf_write(fp, " BFD process priority = %d", data->bfd_process_priority);
 	conf_write(fp, " BFD don't swap = %s", data->bfd_no_swap ? "true" : "false");
-#ifdef _HAVE_SCHED_RT_
 	conf_write(fp, " BFD realtime priority = %u", data->bfd_realtime_priority);
 	if (CPU_COUNT(&data->bfd_cpu_mask)) {
 		get_process_cpu_affinity_string(&data->bfd_cpu_mask, cpu_str, 63);
@@ -598,7 +593,6 @@ dump_global_data(FILE *fp, data_t * data)
 	conf_write(fp, " BFD realtime limit = %" PRI_rlim_t, data->bfd_rlimit_rt);
 #endif
 #endif
-#endif
 #ifdef _WITH_SNMP_VRRP_
 	conf_write(fp, " SNMP vrrp %s", data->enable_snmp_vrrp ? "enabled" : "disabled");
 #endif
