@@ -33,11 +33,9 @@
 #include <netinet/in.h>
 #include <openssl/ssl.h>
 
-#ifdef _WITH_LVS_
-  #include "ip_vs.h"
-#endif
 
 /* local includes */
+#include "ip_vs.h"
 #include "list.h"
 #include "vector.h"
 #include "notify.h"
@@ -73,11 +71,10 @@ typedef struct _real_server {
 	int				tun_flags;	/* tunnel checksum type for gue/gre tunnels */
 #endif
 #endif
-	uint32_t			u_threshold;   /* Upper connection limit. */
-	uint32_t			l_threshold;   /* Lower connection limit. */
+	uint32_t			u_threshold;	/* Upper connection limit. */
+	uint32_t			l_threshold;	/* Lower connection limit. */
 	int				inhibit;	/* Set weight to 0 instead of removing
-							 * the service from IPVS topology.
-							 */
+							 * the service from IPVS topology. */
 	notify_script_t			*notify_up;	/* Script to launch when RS is added to LVS */
 	notify_script_t			*notify_down;	/* Script to launch when RS is removed from LVS */
 	int				alpha;		/* true if alpha mode is default. */
@@ -93,7 +90,7 @@ typedef struct _real_server {
 	bool				set;		/* in the IPVS table */
 	bool				reloaded;	/* active state was copied from old config while reloading */
 	const char			*virtualhost;	/* Default virtualhost for HTTP and SSL health checkers */
-#if defined(_WITH_SNMP_CHECKER_) && defined(_WITH_LVS_)
+#if defined(_WITH_SNMP_CHECKER_)
 	/* Statistics */
 	uint32_t			activeconns;	/* active connections */
 	uint32_t			inactconns;	/* inactive connections */
@@ -142,11 +139,11 @@ typedef struct _virtual_server {
 	struct sockaddr_storage		addr;
 	uint32_t			vfwmark;
 	real_server_t			*s_svr;
+	bool				s_svr_duplicates_rs;
 	uint16_t			af;
 	uint16_t			service_type;
 	bool				ha_suspend;
 	int				ha_suspend_addr_count;
-#ifdef _WITH_LVS_
 	char				sched[IP_VS_SCHEDNAME_MAXLEN];
 	uint32_t			flags;
 	uint32_t			persistence_timeout;
@@ -162,7 +159,6 @@ typedef struct _virtual_server {
 #endif
 #endif
 	uint32_t			persistence_granularity;
-#endif
 	const char			*virtualhost;	/* Default virtualhost for HTTP and SSL healthcheckers
 							   if not set on real servers */
 	int				weight;
@@ -184,7 +180,7 @@ typedef struct _virtual_server {
 	int				smtp_alert;	/* Send email on status change */
 	bool				quorum_state_up; /* Reflects result of the last transition done. */
 	bool				reloaded;	/* quorum_state was copied from old config while reloading */
-#if defined(_WITH_SNMP_CHECKER_) && defined(_WITH_LVS_)
+#if defined(_WITH_SNMP_CHECKER_)
 	/* Statistics */
 	time_t				lastupdated;
 #ifndef _WITH_LVS_64BIT_STATS_
