@@ -762,7 +762,7 @@ vrrp_bfd_thread(thread_ref_t thread)
 	bfd_thread = thread_add_read(master, vrrp_bfd_thread, NULL,
 				     thread->u.f.fd, TIMER_NEVER, false);
 
-	if (thread->type != THREAD_READY_FD)
+	if (thread->type != THREAD_READY_READ_FD)
 		return 0;
 
 	while (read(thread->u.f.fd, &evt, sizeof(bfd_event_t)) != -1)
@@ -892,7 +892,7 @@ vrrp_dispatcher_read(sock_t *sock)
 		}
 
 		if (msghdr.msg_flags & MSG_CTRUNC) {
-			log_message(LOG_INFO, "recvmsg(%d), control message truncated from %zu to %zu bytes"
+			log_message(LOG_INFO, "recvmsg(%d), control message truncated from %zu to %" PRI_MSG_CONTROLLEN " bytes"
 					    , sock->fd_in, sizeof(control_buf), msghdr.msg_controllen);
 			msghdr.msg_controllen = 0;
 		}
@@ -977,7 +977,7 @@ vrrp_dispatcher_read(sock_t *sock)
 #endif
 
 			if (!expected_cmsg)
-				log_message(LOG_INFO, "fd %d, unexpected control msg len %zu, level %d, type %d"
+				log_message(LOG_INFO, "fd %d, unexpected control msg len %" PRI_MSG_CONTROLLEN ", level %d, type %d"
 						    , sock->fd_in, cmsg->cmsg_len
 						    , cmsg->cmsg_level, cmsg->cmsg_type);
 		}
