@@ -34,6 +34,7 @@
 #else
 #include <stdlib.h>
 #endif
+#include <stdbool.h>
 
 /* Local defines */
 #ifdef _MEM_CHECK_
@@ -54,6 +55,10 @@
 
 extern size_t mem_allocated;
 
+#ifdef _MEM_ERR_DEBUG_
+extern bool do_mem_err_debug;
+#endif
+
 /* Memory debug prototypes defs */
 extern void memcheck_log(const char *, const char *, const char *, const char *, int);
 extern void *keepalived_malloc(size_t, const char *, const char *, int)
